You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@nlpcraft.apache.org by ar...@apache.org on 2021/03/26 21:53:13 UTC

[incubator-nlpcraft] branch master updated: Update TimeModel.java

This is an automated email from the ASF dual-hosted git repository.

aradzinski pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/incubator-nlpcraft.git


The following commit(s) were added to refs/heads/master by this push:
     new 9ac2a1a  Update TimeModel.java
9ac2a1a is described below

commit 9ac2a1a377d13bfa847acb6afda8a1515d47193e
Author: Aaron Radzinski <ar...@apache.org>
AuthorDate: Fri Mar 26 14:53:05 2021 -0700

    Update TimeModel.java
---
 .../src/main/scala/org/apache/nlpcraft/examples/time/TimeModel.java  | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/nlpcraft/src/main/scala/org/apache/nlpcraft/examples/time/TimeModel.java b/nlpcraft/src/main/scala/org/apache/nlpcraft/examples/time/TimeModel.java
index de83473..1bdf98e 100644
--- a/nlpcraft/src/main/scala/org/apache/nlpcraft/examples/time/TimeModel.java
+++ b/nlpcraft/src/main/scala/org/apache/nlpcraft/examples/time/TimeModel.java
@@ -40,8 +40,9 @@ import static java.time.format.FormatStyle.*;
  * <p>
  * See 'README.md' file in the same folder for running and testing instructions.
  */
-// Declaring intents on the class level for demo purposes.
-@NCIntent("intent=intent2 term~{tok_id() == 'x:time'} term(city)~{tok_id() == 'nlpcraft:city'}")
+// Declaring intents on the class level + fragment usage for demo purposes.
+@NCIntent("fragment=city term(city)~{tok_id() == 'nlpcraft:city'}")
+@NCIntent("intent=intent2 term~{tok_id() == 'x:time'} fragment(city)")
 @NCIntent("intent=intent1 term={tok_id() == 'x:time'}")
 public class TimeModel extends NCModelFileAdapter {
     // Medium data formatter.